==> eleventy-0.3.4.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.3.4

| Filename                                   | % Lines | % Statements | % Functions | % Branches |
| ------------------------------------------ | ------- | ------------ | ----------- | ---------- |
| `total`                                    | 86.62%  | 86.63%       | 83.38%      | 79.47%     |
| `config.js`                                | 100%    | 100%         | 100%        | 100%       |
| `src/Config.js`                            | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`                          | 48.33%  | 48.33%       | 30.43%      | 19.23%     |
| `src/EleventyCommandCheck.js`              | 100%    | 100%         | 100%        | 87.5%      |
| `src/EleventyConfig.js`                    | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyError.js`                     | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyExtensionMap.js`              | 100%    | 100%         | 100%        | 90%        |
| `src/Template.js`                          | 89.72%  | 89.72%       | 80.95%      | 82.83%     |
| `src/TemplateCache.js`                     | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateCollection.js`                | 90.32%  | 90.63%       | 85.71%      | 83.33%     |
| `src/TemplateConfig.js`                    | 85.19%  | 85.19%       | 62.5%       | 94.44%     |
| `src/TemplateData.js`                      | 97.54%  | 97.54%       | 100%        | 78.13%     |
| `src/TemplateFileSlug.js`                  | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateGlob.js`                      | 93.33%  | 93.33%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`                    | 97.37%  | 97.37%       | 100%        | 92.86%     |
| `src/TemplateMap.js`                       | 97.1%   | 97.1%        | 100%        | 83.33%     |
| `src/TemplatePassthrough.js`               | 83.33%  | 83.33%       | 75%         | 0%         |
| `src/TemplatePassthroughManager.js`        | 62.75%  | 62.75%       | 76.92%      | 66.67%     |
| `src/TemplatePath.js`                      | 97.18%  | 97.18%       | 93.33%      | 95.12%     |
| `src/TemplatePermalink.js`                 | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`                    | 98.73%  | 98.73%       | 100%        | 94.44%     |
| `src/TemplateWriter.js`                    | 81.29%  | 81.29%       | 72.41%      | 76.67%     |
| `src/UserConfig.js`                        | 76.14%  | 76.4%        | 64.29%      | 57.14%     |
| `src/Engines/Ejs.js`                       | 95.45%  | 95.45%       | 85.71%      | 66.67%     |
| `src/Engines/Haml.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`                | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Html.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScriptTemplateLiteral.js` | 93.33%  | 93.33%       | 100%        | 100%       |
| `src/Engines/Liquid.js`                    | 100%    | 100%         | 100%        | 83.33%     |
| `src/Engines/Markdown.js`                  | 90%     | 90%          | 87.5%       | 75%        |
| `src/Engines/Mustache.js`                  | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`                  | 95%     | 95%          | 100%        | 75%        |
| `src/Engines/Pug.js`                       | 100%    | 100%         | 100%        | 75%        |
| `src/Engines/TemplateEngine.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Slug.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Url.js`                       | 100%    | 100%         | 100%        | 100%       |
| `src/Plugins/Pagination.js`                | 94.2%   | 94.2%        | 88.89%      | 88.46%     |
| `src/Util/Capitalize.js`                   | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Pluralize.js`                    | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`                     | 82.14%  | 82.14%       | 69.23%      | 95%        |

==> eleventy-0.5.0.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.5.0

| Filename                                   | % Lines | % Statements | % Functions | % Branches |
| ------------------------------------------ | ------- | ------------ | ----------- | ---------- |
| `total`                                    | 85.02%  | 85.04%       | 83.22%      | 75.26%     |
| `config.js`                                | 100%    | 100%         | 100%        | 100%       |
| `src/Config.js`                            | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`                          | 52.91%  | 52.91%       | 37.5%       | 22.73%     |
| `src/EleventyCommandCheck.js`              | 100%    | 100%         | 100%        | 87.5%      |
| `src/EleventyConfig.js`                    | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyError.js`                     | 100%    | 100%         | 100%        | 100%       |
| `src/EleventyExtensionMap.js`              | 100%    | 100%         | 100%        | 90%        |
| `src/EleventyServe.js`                     | 19.64%  | 19.64%       | 46.15%      | 0%         |
| `src/Template.js`                          | 89.09%  | 89.09%       | 83.33%      | 80.37%     |
| `src/TemplateCache.js`                     | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateCollection.js`                | 90.91%  | 91.18%       | 86.67%      | 83.33%     |
| `src/TemplateConfig.js`                    | 85.19%  | 85.19%       | 62.5%       | 94.44%     |
| `src/TemplateData.js`                      | 97.54%  | 97.54%       | 100%        | 78.13%     |
| `src/TemplateFileSlug.js`                  | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateGlob.js`                      | 93.33%  | 93.33%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`                    | 97.37%  | 97.37%       | 100%        | 92.86%     |
| `src/TemplateMap.js`                       | 98.99%  | 98.99%       | 100%        | 81.82%     |
| `src/TemplatePassthrough.js`               | 83.33%  | 83.33%       | 75%         | 0%         |
| `src/TemplatePassthroughManager.js`        | 63.46%  | 63.46%       | 76.92%      | 66.67%     |
| `src/TemplatePath.js`                      | 97.53%  | 97.53%       | 94.44%      | 96.3%      |
| `src/TemplatePermalink.js`                 | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`                    | 98.73%  | 98.73%       | 100%        | 94.44%     |
| `src/TemplateWriter.js`                    | 83.33%  | 83.33%       | 74.19%      | 78.13%     |
| `src/UserConfig.js`                        | 64.57%  | 64.84%       | 55.26%      | 45.45%     |
| `src/Engines/Ejs.js`                       | 95.45%  | 95.45%       | 85.71%      | 66.67%     |
| `src/Engines/Haml.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`                | 100%    | 100%         | 100%        | 83.33%     |
| `src/Engines/Html.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScriptTemplateLiteral.js` | 93.33%  | 93.33%       | 100%        | 100%       |
| `src/Engines/Liquid.js`                    | 95.52%  | 95.52%       | 96%         | 75%        |
| `src/Engines/Markdown.js`                  | 90%     | 90%          | 87.5%       | 75%        |
| `src/Engines/Mustache.js`                  | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`                  | 91.94%  | 91.94%       | 100%        | 66.67%     |
| `src/Engines/Pug.js`                       | 100%    | 100%         | 100%        | 75%        |
| `src/Engines/TemplateEngine.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Slug.js`                      | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Url.js`                       | 100%    | 100%         | 100%        | 100%       |
| `src/Plugins/Pagination.js`                | 91.58%  | 91.58%       | 92.86%      | 83.33%     |
| `src/Util/Capitalize.js`                   | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Pluralize.js`                    | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`                     | 82.14%  | 82.14%       | 69.23%      | 95%        |
